// components/MultiStepForm.tsx
"use client";
import React, { useState } from "react";

const steps = ["Contact details", "Our services", "Project details", "Review"];

const services = [
  { id: "development", name: "Development", icon: "⚙️" },
  { id: "webdesign", name: "Web Design", icon: "🎨" },
  { id: "marketing", name: "Marketing", icon: "📣" },
  { id: "other", name: "Other", icon: "🔧" },
];

const Form: React.FC = () => {
  const [selectedService, setSelectedService] = useState<string | null>(null);
  const [currentStep, setCurrentStep] = useState(1);

  const handleServiceSelect = (serviceId: string) => {
    setSelectedService(serviceId);
  };

  const handleNextStep = () => {
    setCurrentStep((prevStep) => Math.min(steps.length, prevStep + 1));
  };

  const handlePreviousStep = () => {
    setCurrentStep((prevStep) => Math.max(1, prevStep - 1));
  };

  return (
    <div className="max-w-2xl mx-auto p-6">
      <h1 className="text-3xl font-bold text-center mb-2">
        France Visa Application
      </h1>

      <div className="bg-white rounded-lg shadow-md p-6">
        <h2 className="text-xl font-semibold mb-4">Our services</h2>
        <p className="text-gray-600 mb-6">
          Please select which service you are interested in.
        </p>

        <div className="grid grid-cols-2 gap-4">
          {services.map((service) => (
            <button
              key={service.id}
              onClick={() => handleServiceSelect(service.id)}
              className={`p-4 rounded-lg border ${
                selectedService === service.id
                  ? "border-emerald-600 bg-emerald-50"
                  : "border-gray-200 hover:border-emerald-300"
              } flex items-center space-x-3 transition-colors`}
            >
              <span className="text-2xl bg-emerald-100 p-2 rounded-full">
                {service.icon}
              </span>
              <span className="font-medium">{service.name}</span>
            </button>
          ))}
        </div>
      </div>

      <div className="mt-8 flex justify-between">
        <button
          className="px-6 py-2 border border-emerald-600 text-emerald-600 rounded-md hover:bg-emerald-50 transition-colors"
          onClick={handlePreviousStep}
        >
          Previous step
        </button>
        <button
          className="px-6 py-2 bg-emerald-600 text-white rounded-md hover:bg-emerald-700 transition-colors"
          onClick={handleNextStep}
        >
          Next step
        </button>
      </div>
    </div>
  );
};

export default Form;
